"use strict";
/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.DeployCancelFormatter = void 0;
const ts_types_1 = require("@salesforce/ts-types");
const resultFormatter_1 = require("./resultFormatter");
class DeployCancelFormatter extends resultFormatter_1.ResultFormatter {
    constructor(logger, ux, result) {
        super(logger, ux);
        this.result = result;
    }
    getJson() {
        return this.result.response;
    }
    display() {
        const deployId = ts_types_1.getString(this.result, 'response.id');
        if (this.isSuccess()) {
            this.ux.log(`Successfully canceled ${deployId}`);
        }
        else {
            let errMsg = `Could not cancel ${deployId}`;
            const errMsgDueTo = ts_types_1.getString(this.result, 'response.errorMessage');
            if (errMsgDueTo) {
                errMsg = `${errMsg} Due to: ${errMsgDueTo}`;
            }
            this.ux.error(errMsg);
        }
    }
}
exports.DeployCancelFormatter = DeployCancelFormatter;
//# sourceMappingURL=deployCancelResultFormatter.js.map