import { UX } from '@salesforce/command';
import { Logger } from '@salesforce/core';
import { DeployResult } from '@salesforce/source-deploy-retrieve';
import { FileResponse, MetadataApiDeployStatus, RequestStatus } from '@salesforce/source-deploy-retrieve/lib/src/client/types';
import { ResultFormatter, ResultFormatterOptions } from './resultFormatter';
export interface DeployCommandResult extends MetadataApiDeployStatus {
    deployedSource: FileResponse[];
    outboundFiles: string[];
    deploys: MetadataApiDeployStatus[];
}
export interface DeployCommandAsyncResult extends DeployAsyncStatus {
    deployedSource: FileResponse[];
    outboundFiles: string[];
    deploys: DeployAsyncStatus[];
}
export interface DeployAsyncStatus {
    done: boolean;
    id: string;
    state: 'Queued';
    status: 'Queued';
    timedOut: boolean;
}
export declare class DeployResultFormatter extends ResultFormatter {
    protected result: DeployResult;
    protected fileResponses: FileResponse[];
    constructor(logger: Logger, ux: UX, options: ResultFormatterOptions, result: DeployResult);
    /**
     * Get the JSON output from the DeployResult. The returned JSON shape
     * varies based on:
     *
     * 1. Standard synchronous deploy
     * 2. Asynchronous deploy (wait=0)
     *
     * @returns a JSON formatted result matching the provided type.
     */
    getJson(): DeployCommandResult | DeployCommandAsyncResult;
    /**
     * Displays deploy results in human format.  Output can vary based on:
     *
     * 1. Standard synchronous deploy (no tests run)
     * 2. Asynchronous deploy (wait=0)
     * 3. Checkonly deploy (checkonly=true)
     * 4. Deploy with test results
     */
    display(): void;
    protected hasStatus(status: RequestStatus): boolean;
    protected hasComponents(): boolean;
    protected isRunTestsEnabled(): boolean;
    protected isCheckOnly(): boolean;
    protected getNumResult(field: string): number;
    protected getResponse(): MetadataApiDeployStatus;
    protected displaySuccesses(): void;
    protected displayFailures(): void;
    protected displayTestResults(): void;
}
